@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -327,11 +327,17 @@ $Param{Signature}";
         $LayoutObject->ChallengeTokenCheck();
 
         # get params
-        for my $Parameter (qw(From BounceTo To Subject Body InformSender BounceStateID)) {
+        for my $Parameter (qw(BounceTo To Subject Body InformSender BounceStateID)) {
             $Param{$Parameter}
                 = $Kernel::OM->Get('Kernel::System::Web::Request')->GetParam( Param => $Parameter ) || '';
         }
 
+        # Make sure sender is correct one.
+        $Param{From} = $Kernel::OM->Get('Kernel::System::TemplateGenerator')->Sender(
+            QueueID => $Ticket{QueueID},
+            UserID  => $Self->{UserID},
+        );
+
         my %Error;
 
         # check forward email address
@@ -454,12 +460,19 @@ $Param{Signature}";
             return $Output;
         }
 
+        # Get attributes like sender address.
+        my %Data = $Kernel::OM->Get('Kernel::System::TemplateGenerator')->Attributes(
+            TicketID => $Self->{TicketID},
+            Data     => {},
+            UserID   => $Self->{UserID},
+        );
+
         my $Bounce = $TicketObject->ArticleBounce(
             TicketID    => $Self->{TicketID},
             ArticleID   => $Self->{ArticleID},
             UserID      => $Self->{UserID},
             To          => $Param{BounceTo},
-            From        => $Param{From},
+            From        => $Data{From},
             HistoryType => 'Bounce',
         );
 
@@ -496,7 +509,7 @@ $Param{Signature}";
                 TicketID       => $Self->{TicketID},
                 HistoryType    => 'Bounce',
                 HistoryComment => "Bounced info to '$Param{To}'.",
-                From           => $Param{From},
+                From           => $Data{From},
                 Email          => $Param{Email},
                 To             => $Param{To},
                 Subject        => $Param{Subject},
