@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Modules::CustomerTicketMessage;
@@ -255,7 +255,7 @@ sub Run {
         my ( $NewQueueID, $To ) = split( /\|\|/, $Dest );
         if ( !$To ) {
             $NewQueueID = $ParamObject->GetParam( Param => 'NewQueueID' ) || '';
-            $To = 'System';
+            $To         = 'System';
         }
 
         # fallback, if no destination is given
@@ -472,7 +472,7 @@ sub Run {
 
             # set the correct queue name in $To if it was altered
             if ( $To ne $Tos->{$NewQueueID} ) {
-                $To = $Tos->{$NewQueueID}
+                $To = $Tos->{$NewQueueID};
             }
         }
 
@@ -1181,7 +1181,7 @@ sub _MaskNew {
             Data => {
                 %Param,
                 TypeIDInvalid => $Param{Errors}->{TypeIDInvalid},
-                }
+            }
         );
     }
 
