@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::Auth::Sync::LDAP;
@@ -191,7 +191,10 @@ sub Sync {
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
     # get current user id
-    my $UserID = $UserObject->UserLookup( UserLogin => $Param{User} );
+    my $UserID = $UserObject->UserLookup(
+        UserLogin => $Param{User},
+        Silent    => 1,
+    );
 
     # system permissions
     my %PermissionsEmpty =
@@ -201,11 +204,11 @@ sub Sync {
     my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
 
     # get system groups and create lookup
-    my %SystemGroups = $GroupObject->GroupList( Valid => 1 );
+    my %SystemGroups       = $GroupObject->GroupList( Valid => 1 );
     my %SystemGroupsByName = reverse %SystemGroups;
 
     # get system roles and create lookup
-    my %SystemRoles = $GroupObject->RoleList( Valid => 1 );
+    my %SystemRoles       = $GroupObject->RoleList( Valid => 1 );
     my %SystemRolesByName = reverse %SystemRoles;
 
     # sync user from ldap
@@ -306,7 +309,7 @@ sub Sync {
                             next GROUP;
                         }
 
-                        $GroupObject->GroupMemberAdd(
+                        $GroupObject->PermissionGroupUserAdd(
                             GID        => $SystemGroupsByName{$Group},
                             UID        => $UserID,
                             Permission => {
@@ -515,37 +518,36 @@ sub Sync {
         }
     }
 
-    # compare group permissions from ldap with current user group permissions
+    # Compare group permissions from LDAP with current user group permissions.
     my %GroupPermissionsChanged;
+
     if (%GroupPermissionsFromLDAP) {
+
         PERMISSIONTYPE:
         for my $PermissionType ( @{ $ConfigObject->Get('System::Permission') } ) {
 
             # get current permission for type
-            my %GroupPermissions = $GroupObject->GroupGroupMemberList(
+            my %GroupPermissions = $GroupObject->PermissionUserGroupGet(
                 UserID => $UserID,
                 Type   => $PermissionType,
-                Result => 'HASH',
             );
 
             GROUPID:
             for my $GroupID ( sort keys %SystemGroups ) {
 
-                my $OldPermission = $GroupPermissions{$GroupID};
-                my $NewPermission = $GroupPermissionsFromLDAP{$GroupID}->{$PermissionType};
+                my $OldPermission = $GroupPermissions{$GroupID} ? 1 : 0;
 
-                # if old and new permission for group/type match, do nothing
-                if (
-                    ( $OldPermission && $NewPermission )
-                    ||
-                    ( !$OldPermission && !$NewPermission )
-                    )
-                {
-                    next GROUPID;
-                }
+                # Set the new permission (from LDAP) if exist, if not set it to a default value
+                #   regularly 0 but it LDAP has rw permission set it to 1 as PermissionUserGroupGet()
+                #   gets all system permissions to 1 if stored permission is rw.
+                my $NewPermission = $GroupPermissionsFromLDAP{$GroupID}->{$PermissionType}
+                    || $GroupPermissionsFromLDAP{$GroupID}->{rw} ? 1 : 0;
 
-                # permission for group/type differs - remember
-                $GroupPermissionsChanged{$GroupID}->{$PermissionType} = $NewPermission;
+                # Skip permission if is identical as in the DB
+                next GROUPID if $OldPermission == $NewPermission;
+
+                # Remember the LDAP permission if they are not identical as in the DB.
+                $GroupPermissionsChanged{$GroupID} = $GroupPermissionsFromLDAP{$GroupID};
             }
         }
     }
@@ -558,7 +560,7 @@ sub Sync {
                 Priority => 'notice',
                 Message  => "User: '$Param{User}' sync ldap group $SystemGroups{$GroupID}!",
             );
-            $GroupObject->GroupMemberAdd(
+            $GroupObject->PermissionGroupUserAdd(
                 GID        => $GroupID,
                 UID        => $UserID,
                 Permission => $GroupPermissionsChanged{$GroupID} || \%PermissionsEmpty,
@@ -715,9 +717,8 @@ sub Sync {
     if (%RolePermissionsFromLDAP) {
 
         # get current user roles
-        my %UserRoles = $GroupObject->GroupUserRoleMemberList(
+        my %UserRoles = $GroupObject->PermissionUserRoleGet(
             UserID => $UserID,
-            Result => 'HASH',
         );
 
         ROLEID:
@@ -737,7 +738,7 @@ sub Sync {
                 Priority => 'notice',
                 Message  => "User: '$Param{User}' sync ldap role $SystemRoles{$RoleID}!",
             );
-            $GroupObject->GroupUserRoleMemberAdd(
+            $GroupObject->PermissionRoleUserAdd(
                 UID    => $UserID,
                 RID    => $RoleID,
                 Active => $RolePermissionsFromLDAP{$RoleID} || 0,
