@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::PostMaster::NewTicket;
@@ -23,6 +23,7 @@ our @ObjectDependencies = (
     'Kernel::System::State',
     'Kernel::System::Ticket',
     'Kernel::System::Time',
+    'Kernel::System::Type',
     'Kernel::System::User',
 );
 
@@ -60,7 +61,7 @@ sub Run {
 
     # get queue id and name
     my $QueueID = $Param{QueueID} || die "need QueueID!";
-    my $Queue = $Kernel::OM->Get('Kernel::System::Queue')->QueueLookup(
+    my $Queue   = $Kernel::OM->Get('Kernel::System::Queue')->QueueLookup(
         QueueID => $QueueID,
     );
 
@@ -107,6 +108,22 @@ sub Run {
         }
     }
 
+    my $TypeID;
+
+    if ( $GetParam{'X-OTRS-Type'} ) {
+
+        # Check if type exists
+        $TypeID = $Kernel::OM->Get('Kernel::System::Type')->TypeLookup( Type => $GetParam{'X-OTRS-Type'} );
+
+        if ( !$TypeID ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message =>
+                    "Type $GetParam{'X-OTRS-Type'} does not exist, falling back to default type."
+            );
+        }
+    }
+
     # get sender email
     my @EmailAddresses = $Self->{ParserObject}->SplitAddressLine(
         Line => $GetParam{From},
@@ -190,7 +207,11 @@ sub Run {
     }
 
     # if there is no customer id found!
-    if ( !$GetParam{'X-OTRS-CustomerNo'} ) {
+    if (
+        !$GetParam{'X-OTRS-CustomerNo'}
+        && $ConfigObject->Get('PostMaster::NewTicket::AutoAssignCustomerIDForUnknownCustomers')
+        )
+    {
         $GetParam{'X-OTRS-CustomerNo'} = $GetParam{SenderEmailAddress};
     }
 
@@ -236,7 +257,7 @@ sub Run {
         Lock         => $GetParam{'X-OTRS-Lock'} || 'unlock',
         Priority     => $Priority,
         State        => $State,
-        Type         => $GetParam{'X-OTRS-Type'} || '',
+        TypeID       => $TypeID,
         Service      => $GetParam{'X-OTRS-Service'} || '',
         SLA          => $GetParam{'X-OTRS-SLA'} || '',
         CustomerID   => $GetParam{'X-OTRS-CustomerNo'},
@@ -333,7 +354,7 @@ sub Run {
         next DYNAMICFIELDID if !$DynamicFieldList->{$DynamicFieldID};
         my $Key = 'X-OTRS-DynamicField-' . $DynamicFieldList->{$DynamicFieldID};
 
-        if ( $GetParam{$Key} ) {
+        if ( defined $GetParam{$Key} && length $GetParam{$Key} ) {
 
             # get dynamic field config
             my $DynamicFieldGet = $DynamicFieldObject->DynamicFieldGet(
@@ -366,8 +387,12 @@ sub Run {
     for my $Item ( sort keys %Values ) {
         for my $Count ( 1 .. 16 ) {
             my $Key = $Item . $Count;
-            if ( $GetParam{$Key} && $DynamicFieldListReversed{ $Values{$Item} . $Count } ) {
-
+            if (
+                defined $GetParam{$Key}
+                && length $GetParam{$Key}
+                && $DynamicFieldListReversed{ $Values{$Item} . $Count }
+                )
+            {
                 # get dynamic field config
                 my $DynamicFieldGet = $DynamicFieldObject->DynamicFieldGet(
                     ID => $DynamicFieldListReversed{ $Values{$Item} . $Count },
@@ -394,7 +419,7 @@ sub Run {
 
         my $Key = 'X-OTRS-TicketTime' . $Count;
 
-        if ( $GetParam{$Key} ) {
+        if ( defined $GetParam{$Key} && length $GetParam{$Key} ) {
 
             # get time object
             my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
@@ -428,25 +453,26 @@ sub Run {
 
     # do article db insert
     my $ArticleID = $TicketObject->ArticleCreate(
-        TicketID         => $TicketID,
-        ArticleType      => $GetParam{'X-OTRS-ArticleType'},
-        SenderType       => $GetParam{'X-OTRS-SenderType'},
-        From             => $GetParam{From},
-        ReplyTo          => $GetParam{ReplyTo},
-        To               => $GetParam{To},
-        Cc               => $GetParam{Cc},
-        Subject          => $GetParam{Subject},
-        MessageID        => $GetParam{'Message-ID'},
-        InReplyTo        => $GetParam{'In-Reply-To'},
-        References       => $GetParam{'References'},
-        ContentType      => $GetParam{'Content-Type'},
-        Body             => $GetParam{Body},
-        UserID           => $Param{InmailUserID},
-        HistoryType      => 'EmailCustomer',
-        HistoryComment   => "\%\%$Comment",
-        OrigHeader       => \%GetParam,
-        AutoResponseType => $AutoResponseType,
-        Queue            => $Queue,
+        TicketID           => $TicketID,
+        ArticleType        => $GetParam{'X-OTRS-ArticleType'},
+        SenderType         => $GetParam{'X-OTRS-SenderType'},
+        From               => $GetParam{From},
+        ReplyTo            => $GetParam{ReplyTo},
+        To                 => $GetParam{To},
+        Cc                 => $GetParam{Cc},
+        Subject            => $GetParam{Subject},
+        MessageID          => $GetParam{'Message-ID'},
+        InReplyTo          => $GetParam{'In-Reply-To'},
+        References         => $GetParam{'References'},
+        ContentType        => $GetParam{'Content-Type'},
+        ContentDisposition => $GetParam{'Content-Disposition'},
+        Body               => $GetParam{Body},
+        UserID             => $Param{InmailUserID},
+        HistoryType        => 'EmailCustomer',
+        HistoryComment     => "\%\%$Comment",
+        OrigHeader         => \%GetParam,
+        AutoResponseType   => $AutoResponseType,
+        Queue              => $Queue,
     );
 
     # close ticket if article create failed!
@@ -503,7 +529,7 @@ sub Run {
         next DYNAMICFIELDID if !$DynamicFieldID;
         next DYNAMICFIELDID if !$DynamicFieldList->{$DynamicFieldID};
         my $Key = 'X-OTRS-DynamicField-' . $DynamicFieldList->{$DynamicFieldID};
-        if ( $GetParam{$Key} ) {
+        if ( defined $GetParam{$Key} && length $GetParam{$Key} ) {
 
             # get dynamic field config
             my $DynamicFieldGet = $DynamicFieldObject->DynamicFieldGet(
@@ -536,8 +562,12 @@ sub Run {
     for my $Item ( sort keys %Values ) {
         for my $Count ( 1 .. 16 ) {
             my $Key = $Item . $Count;
-            if ( $GetParam{$Key} && $DynamicFieldListReversed{ $Values{$Item} . $Count } ) {
-
+            if (
+                defined $GetParam{$Key}
+                && length $GetParam{$Key}
+                && $DynamicFieldListReversed{ $Values{$Item} . $Count }
+                )
+            {
                 # get dynamic field config
                 my $DynamicFieldGet = $DynamicFieldObject->DynamicFieldGet(
                     ID => $DynamicFieldListReversed{ $Values{$Item} . $Count },
