@@ -1,9 +1,9 @@
 // --
-// Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (AGPL). If you
-// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+// the enclosed file COPYING for license information (GPL). If you
+// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 // --
 
 "use strict";
@@ -12,105 +12,137 @@ var Core = Core || {};
 Core.UI = Core.UI || {};
 
 /**
- * @namespace
- * @exports TargetNS as Core.UI.TreeSelection
+ * @namespace Core.UI.TreeSelection
+ * @memberof Core.UI
+ * @author OTRS AG
  * @description
- *      Tree Selection for Queue, Service, etc. with JSTree
+ *      Tree Selection for Queue, Service, etc. with JSTree.
  */
 Core.UI.TreeSelection = (function (TargetNS) {
 
+    /**
+     * @private
+     * @name GetChildren
+     * @memberof Core.UI.TreeSelection
+     * @function
+     * @returns {Object|Boolean} Returns elements object or false if no children available.
+     * @param {Object} Elements
+     * @param {String} Index
+     * @param {Object} Data
+     * @description
+     *      Gets all children of a(sub)tree.
+     */
     function GetChildren(Elements, Index, Data) {
-
+        // Copy element structure to avoid call-by-reference problems
+        // when deleting entries while still looping over them
+        var NewElements = Elements;
         $.each(Elements, function(InnerIndex, InnerData) {
             if (typeof InnerData !== 'object') {
                 return false;
             }
             if (InnerData.ID === Data.ChildOf) {
-                Elements[InnerIndex].children.push(Data);
-                delete Elements[Index];
+                NewElements[InnerIndex].children.push(Data);
+                delete NewElements[Index];
             }
         });
 
-        return Elements;
+        return NewElements;
     }
 
+    /**
+     * @private
+     * @name CollectElements
+     * @memberof Core.UI.TreeSelection
+     * @function
+     * @returns {Object|Boolean} Returns elements object or false on error.
+     * @param {Object} Elements
+     * @param {Number} Level
+     * @description
+     *      Collect all elements of a tree.
+     */
     function CollectElements(Elements, Level) {
-
+        // Copy element structure to avoid call-by-reference problems
+        // when deleting entries while still looping over them
+        var NewElements = Elements;
         $.each(Elements, function(Index, Data) {
             if (typeof Data !== 'object') {
                 return false;
             }
             if (Data.Level === Level) {
                 if (Level > 0) {
-                    Elements = GetChildren(Elements, Index, Data);
+                    NewElements = GetChildren(NewElements, Index, Data);
                 }
             }
         });
 
-        return Elements;
+        return NewElements;
     }
 
     /**
+     * @name BuildElementsArray
+     * @memberof Core.UI.TreeSelection
      * @function
+     * @returns {Object} Returns an object which is suitable for passing to JSTree in order to build a tree selection.
+     * @param {jQueryObject} $Element - The select element which contains the data.
+     * @param {Boolean} Sort - Whether to sort the elements alphabetically (optional, default: true)
      * @description
      *      This function receives a select element which was built
      *      with TreeView => 1 (= intended elements) and builds a
      *      javascript object from it which contains all the elements
      *      and their children.
-     * @param {jQueryObject} $Element
-     *      The select element which contains the data
-     * @return
-     *      Returns an object which is suitable for passing to JSTree in order
-     *      to build a tree selection.
      */
-    function BuildElementsArray($Element) {
-
+    TargetNS.BuildElementsArray = function($Element, Sort) {
         var Elements = [],
             Level,
             HighestLevel = 0;
 
+        if (typeof Sort === 'undefined') {
+            Sort = true;
+        }
+
         $Element.find('option').each(function() {
 
-            // get number of trailing spaces in service name to
+            // Get number of trailing spaces in service name to
             // distinguish the level (2 spaces = 1 level)
-            var ElementID       = $(this).attr('value'),
+            var ElementID = $(this).attr('value'),
                 ElementDisabled = $(this).is(':disabled'),
-                ElementName     = $(this).text(),
+                ElementName = Core.App.EscapeHTML($(this).text()),
+                ElementSelected = $(this).is(':selected'),
                 ElementNameTrim = ElementName.replace(/(^[\xA0]+)/g, ''),
-                CurrentLevel    = (ElementName.length - ElementNameTrim.length) / 2,
+                CurrentLevel = (ElementName.length - ElementNameTrim.length) / 2,
                 ChildOf = 0,
                 ElementIndex = 0,
                 CurrentElement;
 
-            // skip entry if no ID (should only occur for the leading empty element, '-')
+            // Skip entry if no ID (should only occur for the leading empty element, '-')
             // also skip entries which only contain '------------' as visible text (e.g. in AgentLinkObject)
-            if ( !ElementID || ElementID === "||-" || ( ElementDisabled && ElementName.match(/^-+$/) ) ) {
+            if (!ElementID || ElementID === "||-" || (ElementDisabled && ElementName.match(/^-+$/))) {
                 return true;
             }
 
-            // determine wether this element is a child of a preceding element
+            // Determine whether this element is a child of a preceding element
             // therefore, take the last element we have added to our elements
             // array and compare if to the current element
-            if ( Elements.length && CurrentLevel > 0 ) {
+            if (Elements.length && CurrentLevel > 0) {
 
-                // if the current level is bigger than the last known level,
+                // If the current level is bigger than the last known level,
                 // we're dealing with a child element of the last element
-                if ( CurrentLevel > Elements[Elements.length - 1].Level ) {
+                if (CurrentLevel > Elements[Elements.length - 1].Level) {
                     ChildOf = Elements[Elements.length - 1].ID;
                 }
 
-                // if both levels equal eachother, we have a sibling and can
+                // If both levels equal each other, we have a sibling and can
                 // re-use the parent (= the ChildOf value) of the last element
-                else if ( CurrentLevel === Elements[Elements.length - 1].Level ) {
+                else if (CurrentLevel === Elements[Elements.length - 1].Level) {
                     ChildOf = Elements[Elements.length - 1].ChildOf;
                 }
 
-                // in other cases, we have an element of a lower level but not
+                // In other cases, we have an element of a lower level but not
                 // of the first level, so we walk through all yet saved elements
                 // (bottom up) and find the next element with a lower level
                 else {
-                    for ( ElementIndex = Elements.length; ElementIndex >= 0; ElementIndex-- ) {
-                        if ( CurrentLevel > Elements[ElementIndex - 1].Level ) {
+                    for (ElementIndex = Elements.length; ElementIndex >= 0; ElementIndex--) {
+                        if (CurrentLevel > Elements[ElementIndex - 1].Level) {
                             ChildOf = Elements[ElementIndex - 1].ID;
                             break;
                         }
@@ -119,22 +151,31 @@ Core.UI.TreeSelection = (function (TargetNS) {
             }
 
             // In case of disabled elements, the ID is always "-", which causes duplications.
-            // Therefore, we assign a random ID to avoid conflicts.
-            ElementID = (ElementID === '-') ? Math.floor((Math.random() * 100000) + 1) : ElementID;
+            //   Therefore, we assign an auto-generated ID to avoid conflicts. But make sure to
+            //   check if element is indeed disabled, because the dash value might be allowed.
+            //   See bug#10055 and bug#12528 for more information.
+            if (ElementDisabled && ElementID === '-') {
+                ElementID = Core.UI.GetID();
+            }
 
-            // collect data of current service and add it to elements array
+            // Collect data of current service and add it to elements array
+            /*eslint-disable camelcase */
             CurrentElement = {
-                ID:       ElementID,
-                Name:     ElementNameTrim,
-                Level:    CurrentLevel,
-                ChildOf:  ChildOf,
+                ID: ElementID,
+                Name: ElementNameTrim,
+                Level: CurrentLevel,
+                ChildOf: ChildOf,
                 children: [],
-                data:     ElementNameTrim,
-                attr: {
+                text: ElementNameTrim,
+                state: {
+                    selected: ElementSelected
+                },
+                li_attr: {
                     'data-id': ElementID,
-                    'class' : (ElementDisabled) ? 'Disabled' : ''
+                    'class': (ElementDisabled) ? 'Disabled' : ''
                 }
             };
+            /*eslint-enable camelcase */
             Elements.push(CurrentElement);
 
             if (CurrentLevel > HighestLevel) {
@@ -142,51 +183,56 @@ Core.UI.TreeSelection = (function (TargetNS) {
             }
         });
 
-        Elements.sort(function(a, b) {
-            if (a.Level - b.Level === 0) {
-                return (a.Name.localeCompare(b.Name));
-            }
-            else {
-                return (a.Level - b.Level);
-            }
-        });
+        if (Sort) {
+            Elements.sort(function(a, b) {
+                if (a.Level - b.Level === 0) {
+                    return (a.Name.localeCompare(b.Name));
+                }
+                else {
+                    return (a.Level - b.Level);
+                }
+            });
+        }
 
-        // go through all levels and collect the elements and their children
+        // Go through all levels and collect the elements and their children
         for (Level = HighestLevel; Level >= 0; Level--) {
             Elements = CollectElements(Elements, Level);
         }
 
-        return Elements;
-    }
+        Elements.HighestLevel = HighestLevel;
 
-      /**
+        return Elements;
+    };
+
+    /**
+     * @name ShowTreeSelection
+     * @memberof Core.UI.TreeSelection
      * @function
-     * @private
-     * @return nothing
-     * @description Open the tree view selection dialog
+     * @returns {Boolean} Returns false on error.
+     * @param {jQueryObject} $TriggerObj - Object for which the event was triggered.
+     * @description
+     *      Open the tree view selection dialog.
      */
     TargetNS.ShowTreeSelection = function($TriggerObj) {
 
-        var $TreeObj       = $('<div id="JSTree"><ul></ul></div>'),
-            $SelectObj     = $TriggerObj.prevAll('select'),
-            SelectSize     = $SelectObj.attr('size'),
-            SelectedID     = $SelectObj.val(),
-            Multiple       = ($SelectObj.attr('multiple') !== '' && $SelectObj.attr('multiple') !== undefined) ? true : false,
-            ElementCount   = $SelectObj.find('option').length,
-            DialogTitle    = $SelectObj.parent().prev('label').clone().children().remove().end().text(),
-            Elements       = {},
-            InDialog       = false,
+        var $TreeObj = $('<div id="JSTree"><ul></ul></div>'),
+            $SelectObj = $TriggerObj.prevAll('select'),
+            SelectSize = $SelectObj.attr('size'),
+            Multiple = ($SelectObj.attr('multiple') !== '' && $SelectObj.attr('multiple') !== undefined) ? true : false,
+            ElementCount = $SelectObj.find('option').length,
+            DialogTitle = $SelectObj.parent().prev('label').clone().children().remove().end().text(),
+            Elements = {},
+            InDialog = false,
             StyleSheetURL,
-            $SelectedNodesObj,
+            SelectedNodesTree,
             SelectedNodes = [],
-            $CurrentTreeObj,
             $CurrentFocusedObj;
 
         if (!$SelectObj) {
             return false;
         }
 
-        // determine if we are in a dialog
+        // Determine if we are in a dialog
         if ($SelectObj.closest('.Dialog').length) {
             InDialog = true;
         }
@@ -209,101 +255,89 @@ Core.UI.TreeSelection = (function (TargetNS) {
         DialogTitle = DialogTitle.substr(0, DialogTitle.length - 1);
         DialogTitle = DialogTitle.replace(/^\*\s+/, '');
 
-        // check if there are elements to select from
+        // Check if there are elements to select from
         if (ElementCount === 1 && $SelectObj.find('option').text() === '-') {
             alert(Core.Config.Get('NoElementsToSelectFromMsg'));
             return false;
         }
 
-        Elements = BuildElementsArray($SelectObj);
+        Elements = Core.UI.TreeSelection.BuildElementsArray($SelectObj);
 
-        // set StyleSheetURL in order to correctly load the CSS for treeview
+        // Set StyleSheetURL in order to correctly load the CSS for treeview
         StyleSheetURL = Core.Config.Get('WebPath') + 'skins/Agent/default/css/thirdparty/jstree-theme/default/style.css';
 
+        /*eslint-disable camelcase */
         $TreeObj.jstree({
-            "core": {
-                "animation" : 70
+            core: {
+                animation: 70,
+                data: Elements,
+                multiple: ((SelectSize && Multiple) || Multiple) ? true : false,
+                expand_selected_onload: true,
+                themes: {
+                    theme: 'default',
+                    icons: false,
+                    responsive: true,
+                    variant: 'small',
+                    url: StyleSheetURL
+                }
             },
-            "ui": {
-                "select_multiple_modifier" : ((SelectSize && Multiple) || Multiple) ? 'on' : 'ctrl',
-                "select_limit" : ((SelectSize && Multiple) || Multiple) ? -1 : 1
+            search: {
+                show_only_matches: true,
+                show_only_matches_children: true
             },
-            "search": {
-                "show_only_matches" : true
-            },
-            "json_data" : {
-                "data" : Elements
-            },
-            "themes" : {
-                "theme" : "default",
-                "icons" : false,
-                "url": StyleSheetURL
-            },
-            "plugins" : [ "themes", "json_data", "ui", "hotkeys", "search" ]
+            plugins: [ 'search' ]
         })
-        .bind("select_node.jstree", function (event, data) {
-            if (data.rslt.obj.hasClass('Disabled')) {
-                $TreeObj.jstree("deselect_node", data.rslt.obj);
+        /*eslint-enable camelcase */
+        .bind('select_node.jstree', function (node, selected, event) {
+            var $Node = $('#' + selected.node.id);
+            if ($Node.hasClass('Disabled') || !$Node.is(':visible')) {
+                $TreeObj.jstree('deselect_node', selected.node);
             }
-            $TreeObj.jstree("toggle_node", data.rslt.obj);
+            $TreeObj.jstree('toggle_node', selected.node);
 
-            // if we are already in a dialog, we don't use the submit
+            // If we are already in a dialog, we don't use the submit
             // button for the tree selection, so we need to apply the changes 'live'
             if (InDialog) {
 
-                // reset selected nodes list
+                // Reset selected nodes list
                 SelectedNodes = [];
 
-                // get selected nodes
-                $SelectedNodesObj = $TreeObj.jstree("get_selected");
-                $SelectedNodesObj.each(function() {
-                    SelectedNodes.push($(this).attr('data-id'));
+                // Get selected nodes
+                SelectedNodesTree = $TreeObj.jstree('get_selected');
+                $.each(SelectedNodesTree, function () {
+                    SelectedNodes.push($('#' + Core.App.EscapeSelector(this)).data('id'));
                 });
 
-                // set selected nodes as selected in initial select box
+                // Set selected nodes as selected in initial select box
                 // (which is hidden but is still used for the action)
                 $SelectObj.val(SelectedNodes);
             }
 
-            // if the node has really been selected (not initially by the code, but by using keyboard or mouse)
+            // If the node has really been selected (not initially by the code, but by using keyboard or mouse)
             // we need to check if we can now select the submit button
-            if ((data.rslt.e && data.rslt.e.type !== undefined) && !InDialog && !Multiple) {
+            if ((event && event.type !== undefined) && !InDialog && !Multiple) {
                 $TreeObj.next('#SubmitTree').focus();
             }
 
         })
-        .bind("deselect_node.jstree", function (event, data) {
-
-            // if we are already in a dialog, we don't use the submit
+        .bind('deselect_node.jstree', function () {
+            // If we are already in a dialog, we don't use the submit
             // button for the tree selection, so we need to apply the changes 'live'
             if (InDialog) {
 
-                // reset selected nodes list
+                // Reset selected nodes list
                 SelectedNodes = [];
 
-                // get selected nodes
-                $SelectedNodesObj = $TreeObj.jstree("get_selected");
-                $SelectedNodesObj.each(function() {
-                    SelectedNodes.push($(this).attr('data-id'));
+                // Get selected nodes
+                SelectedNodesTree = $TreeObj.jstree('get_selected');
+                $.each(SelectedNodesTree, function () {
+                    SelectedNodes.push($('#' + Core.App.EscapeSelector(this)).data('id'));
                 });
 
-                // set selected nodes as selected in initial select box
+                // Set selected nodes as selected in initial select box
                 // (which is hidden but is still used for the action)
                 $SelectObj.val(SelectedNodes);
             }
-        })
-        .bind("loaded.jstree", function (event, data) {
-
-            if (SelectedID) {
-                if (typeof SelectedID === 'object') {
-                    $.each(SelectedID, function(Index, Data) {
-                        $TreeObj.jstree("select_node", $TreeObj.find('li[data-id="' + Data + '"]'));
-                    });
-                }
-                else {
-                    $TreeObj.jstree("select_node", $TreeObj.find('li[data-id="' + SelectedID + '"]'));
-                }
-            }
         });
 
         // If we are not already in a dialog, open up one
@@ -326,14 +360,14 @@ Core.UI.TreeSelection = (function (TargetNS) {
             $TriggerObj.addClass('TreeSelectionVisible');
         }
 
-        // get the element which is currently being focused and set the focus to the search field
+        // Get the element which is currently being focused and set the focus to the search field
         $CurrentFocusedObj = document.activeElement;
         $('#TreeSearch').find('input').focus();
 
         $('#TreeSearch').find('input').bind('keyup', function() {
-            $TreeObj.jstree("search", $(this).val());
+            $TreeObj.jstree('search', $(this).val());
 
-            // make sure subtrees of matches nodes are expandable
+            // Make sure sub-trees of matched nodes are expanded
             $('.jstree-search')
                 .parent()
                 .removeClass('jstree-open')
@@ -345,33 +379,41 @@ Core.UI.TreeSelection = (function (TargetNS) {
 
         $('#TreeSearch').find('span').bind('click', function() {
             $(this).prev('input').val('');
-            $TreeObj.jstree("clear_search");
+            $TreeObj.jstree('clear_search');
         });
 
         $('#TreeContainer').find('input#SubmitTree').bind('click', function() {
-            var $SelectedObj = $TreeObj.jstree("get_selected");
-            if (typeof $SelectedObj === 'object' && $SelectedObj.attr('data-id')) {
-                if ($SelectedObj.length > 1) {
+            var SelectedObj = $TreeObj.jstree('get_selected', true),
+                $Node;
+            if (typeof SelectedObj === 'object' && SelectedObj[0]) {
+                if (SelectedObj.length > 1) {
 
-                    $SelectedObj.each(function() {
-                        SelectedNodes.push($(this).attr('data-id'));
+                    $(SelectedObj).each(function() {
+                        var $SelectedNode = $('#' + this.id);
+                        SelectedNodes.push($SelectedNode.attr('data-id'));
                     });
                     $SelectObj
                         .val(SelectedNodes)
                         .trigger('change');
                 }
                 else {
-                    if ($SelectedObj.attr('data-id') !== $SelectObj.val()) {
+                    $Node = $('#' + SelectedObj[0].id);
+                    if ($Node.attr('data-id') !== $SelectObj.val()) {
                         $SelectObj
-                            .val($SelectedObj.attr('data-id'))
+                            .val($Node.attr('data-id'))
                             .trigger('change');
                     }
                 }
             }
+            else {
+                $SelectObj
+                    .val('')
+                    .trigger('change');
+            }
             Core.UI.Dialog.CloseDialog($('.Dialog'));
         });
 
-        // when the dialog is closed, give the last focused element the focus again
+        // When the dialog is closed, give the last focused element the focus again
         Core.App.Subscribe('Event.UI.Dialog.CloseDialog.Close', function(Dialog) {
             if ($(Dialog).find('#TreeContainer').length && !$(Dialog).find('#SearchForm').length) {
                 $CurrentFocusedObj.focus();
@@ -380,23 +422,25 @@ Core.UI.TreeSelection = (function (TargetNS) {
     };
 
     /**
+     * @name InitTreeSelection
+     * @memberof Core.UI.TreeSelection
      * @function
-     * @private
-     * @return nothing
-     * @description to bind click event no tree selection icons next to select boxes
+     * @description
+     *      To bind click event no tree selection icons next to select boxes.
      */
     TargetNS.InitTreeSelection = function() {
-        $('.Field, fieldset').off('click.ShowTreeSelection').on('click.ShowTreeSelection', '.ShowTreeSelection', function (Event) {
+        $('.Field, fieldset').off('click.ShowTreeSelection').on('click.ShowTreeSelection', '.ShowTreeSelection', function () {
             Core.UI.TreeSelection.ShowTreeSelection($(this));
             return false;
         });
     };
 
     /**
+     * @name InitDynamicFieldTreeViewRestore
+     * @memberof Core.UI.TreeSelection
      * @function
-     * @private
-     * @return nothing
-     * @description Initially display dynamic fields with TreeMode = 1 correctly
+     * @description
+     *      Initially display dynamic fields with TreeMode = 1 correctly.
      */
     TargetNS.InitDynamicFieldTreeViewRestore = function() {
         $('.DynamicFieldWithTreeView').each(function() {
@@ -414,10 +458,16 @@ Core.UI.TreeSelection = (function (TargetNS) {
     };
 
     /**
+     * @name RestoreDynamicFieldTreeView
+     * @memberof Core.UI.TreeSelection
      * @function
-     * @private
-     * @return nothing
-     * @description Restores tree view (intended values) for dynamic fields
+     * @returns {Boolean} False on error.
+     * @param {jQueryObject} $FieldObj
+     * @param {Array} Data
+     * @param {Boolean} CheckClass
+     * @param {Number} AJAXUpdate
+     * @description
+     *      Restores tree view (intended values) for dynamic fields.
      */
     TargetNS.RestoreDynamicFieldTreeView = function($FieldObj, Data, CheckClass, AJAXUpdate) {
 
@@ -428,7 +478,6 @@ Core.UI.TreeSelection = (function (TargetNS) {
             Disabled,
             DisabledAttr,
             SelectData = [],
-            LastElement,
             NeededSpaces,
             Spaces,
             i;
@@ -441,12 +490,12 @@ Core.UI.TreeSelection = (function (TargetNS) {
 
         $.each(Data, function(index, OptionData) {
 
-            Key       = OptionData[0] || '';
-            Value     = OptionData[1] || '';
-            Spaces    = '';
+            Key = OptionData[0] || '';
+            Value = OptionData[1] || '';
+            Spaces = '';
             NeededSpaces = 0;
-            Selected  = OptionData[2] || false;
-            Disabled  = OptionData[3] || false;
+            Selected = OptionData[2] || false;
+            Disabled = OptionData[3] || false;
 
             if (AJAXUpdate === 1) {
                 Selected = OptionData[3];
@@ -476,10 +525,10 @@ Core.UI.TreeSelection = (function (TargetNS) {
             }
 
             SelectData.push({
-                'Key'          : Key,
-                'Value'        : Value,
-                'SelectedAttr' : SelectedAttr,
-                'DisabledAttr' : DisabledAttr
+                'Key': Key,
+                'Value': Value,
+                'SelectedAttr': SelectedAttr,
+                'DisabledAttr': DisabledAttr
             });
         });
 
@@ -497,13 +546,12 @@ Core.UI.TreeSelection = (function (TargetNS) {
             return 0;
         });
 
-        $.each(SelectData, function(index, Data) {
-            $FieldObj.append('<option value="' + Data.Key + '"' + Data.SelectedAttr + Data.DisabledAttr + '>' + Data.Value + '</option>');
+        $.each(SelectData, function(index, SelectedData) {
+            $FieldObj.append('<option value="' + SelectedData.Key + '"' + SelectedData.SelectedAttr + SelectedData.DisabledAttr + '>' + SelectedData.Value + '</option>');
         });
 
         $FieldObj.addClass('TreeViewRestored');
     };
 
-
     return TargetNS;
 }(Core.UI.TreeSelection || {}));
